<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>Fett</translation>
    </message>
    <message>
        <location filename="../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
</context>
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../obconf.ui" line="14"/>
        <source>Window Manager Preferences</source>
        <translation>Einstellungen des Fenstermanagers</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="26"/>
        <source>Theme</source>
        <translation>Thema</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="31"/>
        <source>Appearance</source>
        <translation>Erscheinungsbild</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="36"/>
        <source>Font</source>
        <translation>Schrift</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="41"/>
        <location filename="../obconf.ui" line="102"/>
        <source>Windows</source>
        <translation>Fenster</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="46"/>
        <source>Move &amp; Resize</source>
        <translation>Verschieben &amp; Größe ändern</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="51"/>
        <source>Mouse</source>
        <translation>Maus</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="56"/>
        <source>Desktops</source>
        <translation>Arbeitsflächen</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="61"/>
        <source>Margins</source>
        <translation>Ränder</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="66"/>
        <source>Dock</source>
        <translation>Dock</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="84"/>
        <source>&amp;Install a new theme...</source>
        <translation>Ein neues Thema &amp;installieren...</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="91"/>
        <source>Create a theme &amp;archive (.obt)...</source>
        <translation>Themen&amp;archiv erstellen (.obt)...</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="108"/>
        <source>&amp;Windows retain a border when undecorated</source>
        <translation>&amp;Fenster behalten einen Rand, wenn sie nicht dekoriert sind</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="115"/>
        <source>A&amp;nimate iconify and restore</source>
        <translation>&amp;Animiere das Minimieren und Wiederherstellen</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="125"/>
        <source>Window Titles</source>
        <translation>Fenstertitel</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="131"/>
        <source>Button order:</source>
        <translation>Schaltflächenanordnung:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="141"/>
        <source>N: Window icon
L: Window label (Title)
I: Iconify (Minimize)
M: Maximize
C: Close
S: Shade (Roll up)
D: Omnipresent (On all desktops)</source>
        <translation>N: Fenstersymbol
L: Fenstertitel
I: Minimieren
M: Maximieren
C: Schließen
S: Einklappen
D: Präsent auf allen Arbeitsflächen</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="219"/>
        <source>&amp;Active window title: </source>
        <translation>&amp;Aktiver Fenstertitel: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="229"/>
        <source>&amp;Inactive window title: </source>
        <translation>&amp;Inaktiver Fenstertitel: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="239"/>
        <source>Menu &amp;header: </source>
        <translation>Menü&amp;überschrift: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="249"/>
        <source>&amp;Menu Item: </source>
        <translation>Menüelement: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="259"/>
        <source>Active &amp;On-screen display: </source>
        <translation>Aktive &amp;Bildschirmanzeige: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="269"/>
        <source>Inactive O&amp;n-screen display: </source>
        <translation>Inaktive Bildschirma&amp;nzeige: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="283"/>
        <source>Focus &amp;new windows when they appear</source>
        <translation>Fokussiere &amp;neue Fenster beim Erscheinen</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="290"/>
        <source>&amp;Place new windows under the mouse pointer</source>
        <translation>&amp;Platziere neue Fenster unter den Mauszeiger</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="297"/>
        <source>&amp;Center new windows when they are placed</source>
        <translation>&amp;Zentriere neue Fenster</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="306"/>
        <source>Prefer to place new windows &amp;on:</source>
        <translation>Platziere vorzugsweise neue Fenster &amp;auf:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="317"/>
        <source>All monitors</source>
        <translation>Alle Bildschirme</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="322"/>
        <source>The active monitor</source>
        <translation>Der aktive Bildschirm</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="327"/>
        <source>The monitor with the mouse</source>
        <translation>Der Bildschirm auf dem sich der Mauszeiger befindet</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="332"/>
        <source>Primary monitor</source>
        <translation>Primärer Bildschirm</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="342"/>
        <source>Primary Monitor</source>
        <translation>Primärer Bildschirm</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="348"/>
        <source>The primary monitor is where Openbox will place dialogs, such as the one used for cycling windows.</source>
        <translation>Der primäre Bildschirm ist derjenige, auf dem Openbox Dialoge platziert, wie beispielsweise diejenigen, die zum Wechseln von Fenstern verwendet werden.</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="358"/>
        <source>Primary &amp;monitor:</source>
        <translation>Primärer &amp;Bildschirm:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="369"/>
        <source>Fixed Monitor</source>
        <translation>Festgelegter Bildschirm</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="374"/>
        <source>Active Monitor</source>
        <translation>Aktiver Bildschirm</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="379"/>
        <source>Monitor With Mouse Pointer</source>
        <translation>Bildschirm mit Mauszeiger</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="387"/>
        <source>&amp;Fixed monitor:</source>
        <translation>&amp;Festgelegter Bildschirm:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="427"/>
        <source>Moving and Resizing Windows</source>
        <translation>Verschieben und Größenänderung von Fenstern</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="433"/>
        <source>Update the window contents while &amp;resizing</source>
        <translation>Fensterinhalt während &amp;Größenänderungen anzeigen</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="440"/>
        <source>Drag &amp;threshold distance:</source>
        <translation>Abstand beim &amp;Verschieben:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="460"/>
        <source>Amount of resistance against other &amp;windows:</source>
        <translation>Widerstand gegenüber anderen &amp;Fenstern:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="480"/>
        <source>Amount of resistance against screen &amp;edges:</source>
        <translation>Widerstand gegenüber &amp;Bildschirmrändern:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="500"/>
        <source>&amp;Amount of time to wait before switching:</source>
        <translation>&amp;Verzögerung vor dem Arbeitsflächenwechsel:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="520"/>
        <source>&amp;Switch desktops when moving a window past the screen edge</source>
        <translation>Arbeitsfläche beim Verschieben des Fensters über ihren Rand &amp;wechseln</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="530"/>
        <source>Information Dialog</source>
        <translation>Informationsdialog</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="537"/>
        <location filename="../obconf.ui" line="566"/>
        <source>Centered</source>
        <translation>Zentriert</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="542"/>
        <source>From left edge</source>
        <translation>Vom linken Rand</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="547"/>
        <source>From right edge</source>
        <translation>Vom rechten Rand</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="555"/>
        <source>Fixed &amp;y position:</source>
        <translation>Festgelegte &amp;y-Position (Pixel):</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="571"/>
        <source>From top edge</source>
        <translation>Vom oberen Rand</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="576"/>
        <source>From bottom edge</source>
        <translation>Vom unteren Rand</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="584"/>
        <source>Information dialog&apos;s &amp;position:</source>
        <translation>&amp;Position des Informationsdialogs:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="594"/>
        <source>Fixed &amp;x position:</source>
        <translation>Festgelegte &amp;x-Position (Pixel):</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="604"/>
        <source>Show &amp;information dialog:</source>
        <translation>&amp;Informationsdialog anzeigen:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="629"/>
        <source>When resizing terminal windows</source>
        <translation>Bei Größenänderung von Terminalfenstern</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="634"/>
        <source>Always</source>
        <translation>Immer</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="639"/>
        <source>Never</source>
        <translation>Nie</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="648"/>
        <source>Centered on the window</source>
        <translation>Zentriert auf dem Fenster</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="653"/>
        <source>Above the window</source>
        <translation>Oberhalb des Fensters</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="658"/>
        <source>Fixed position on screen</source>
        <translation>Feste Position auf dem Bildschirm</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="689"/>
        <source>Focusing Windows</source>
        <translation>Fokussieren von Fenstern</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="698"/>
        <source>Focus windows when the mouse pointer moves over them</source>
        <translation>Fenster &amp;fokussieren, wenn sich der Mauszeiger über ihnen befindet</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="710"/>
        <source>&amp;Delay before focusing and raising windows:</source>
        <translation>&amp;Verzögerung vor dem Fokussieren und Hervorheben:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="730"/>
        <source>Move focus under the mouse when &amp;switching desktops</source>
        <translation>Beim &amp;Wechsel von Arbeitsflächen Fokus unter den Mauszeiger bringen</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="737"/>
        <source>Move focus &amp;under the mouse when the mouse is not moving</source>
        <translation>Fokus &amp;unter die Maus bringen, wenn diese nicht bewegt wird</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="744"/>
        <source>&amp;Raise windows when the mouse pointer moves over them</source>
        <translation>Fenster &amp;hervorheben, wenn sich der Mauszeiger darüber befindet</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="756"/>
        <source>Titlebar</source>
        <translation>Fenstertitel</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="762"/>
        <source>Double click on the &amp;titlebar:</source>
        <translation>Doppelklick auf den Fenster&amp;titel:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="773"/>
        <source>Maximizes the window</source>
        <translation>Maximiert das Fenster</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="778"/>
        <source>Shades the window</source>
        <translation>Rollt das Fenster ein</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="786"/>
        <source>Double click ti&amp;me:</source>
        <translation>&amp;Intervall für Doppelklick:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="826"/>
        <source>&amp;Show a notification when switching desktops</source>
        <translation>Benachrichtigung beim Arbeitsflächen&amp;wechsel anzeigen</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="833"/>
        <source>&amp;Amount of time to show the notification for:</source>
        <translation>&amp;Dauer, für die die Benachrichtigung angezeigt wird:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="856"/>
        <source>&amp;Number of desktops: </source>
        <translation>An&amp;zahl an Arbeitsflächen: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="879"/>
        <source>&amp;Desktop names:</source>
        <translation>&amp;Bezeichnungen der Arbeitsflächen:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="893"/>
        <source>Desktop Margins</source>
        <translation>Arbeitsflächenränder</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="899"/>
        <source>Desktop margins are reserved areas on the edge of your screen.  New windows will not be placed within a margin, and maximized windows will not cover them.</source>
        <translation>Arbeitsflächenränder sind reservierte Bereiche am Rand des Bildschirms. Neue Fenster werden dort nicht platziert und maximierte Fenster überdecken diese Bereiche nicht.</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="909"/>
        <source>Left:</source>
        <translation>Links:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="923"/>
        <location filename="../obconf.ui" line="944"/>
        <location filename="../obconf.ui" line="965"/>
        <location filename="../obconf.ui" line="986"/>
        <source>px</source>
        <translation>Pixel (px)</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="930"/>
        <source>Top:</source>
        <translation>Oben:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="951"/>
        <source>Right:</source>
        <translation>Rechts:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="972"/>
        <source>Bottom:</source>
        <translation>Unten:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1013"/>
        <source>The dock is a special container for &quot;dockapps&quot;, or dock applications.  It is not visible on screen until a dockapp is run.  Dockapps can be used to show things like a clock, or to provide you with a system tray.</source>
        <translation>Das &quot;Dock&quot; ist ein graphisches Objekt zum Vorhalten sogenannter Dock-Anwendungen (&quot;dockapps&quot;), die z. B. eine Uhr oder Benachrichtigungen anzeigen können.
Das Dock wird erst nach dem Starten von Dock-Anwendungen sichtbar.</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1029"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1041"/>
        <source>&amp;Position:</source>
        <translation>&amp;Position:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1055"/>
        <source>Top Left</source>
        <translation>Oben Links</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1060"/>
        <source>Top</source>
        <translation>Oben</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1065"/>
        <source>Top Right</source>
        <translation>Oben Rechts</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1070"/>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1075"/>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1080"/>
        <source>Bottom Left</source>
        <translation>Unten links</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1085"/>
        <source>Bottom</source>
        <translation>Unten</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1090"/>
        <source>Bottom Right</source>
        <translation>Unten rechts</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1095"/>
        <source>Floating</source>
        <translation>Schwebend</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1109"/>
        <source>&amp;Floating position:</source>
        <translation>&amp;Schwebeposition:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1134"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1150"/>
        <source>Allow &amp;windows to be placed within the dock&apos;s area</source>
        <translation>Positionieren von &amp;Fenstern über dem Dock erlauben</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1157"/>
        <source>&amp;Orientation: </source>
        <translation>&amp;Ausrichtung: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1171"/>
        <source>Vertical</source>
        <translation>Vertikal</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1176"/>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1187"/>
        <source>Stacking</source>
        <translation>Ebenen</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1193"/>
        <source>Keep dock &amp;above other windows</source>
        <translation>Immer im &amp;Vordergrund</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1200"/>
        <source>A&amp;llow dock to be both above and below windows</source>
        <translation>Dock sowohl über als auch unter Fenstern zu&amp;lassen</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1207"/>
        <source>Keep dock &amp;below other windows</source>
        <translation>Immer im &amp;Hintergrund</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1217"/>
        <source>Hiding</source>
        <translation>Ausblenden</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1223"/>
        <source>&amp;Delay before hiding:</source>
        <translation>&amp;Verzögerung vor dem &amp;Ausblenden:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1233"/>
        <source>Delay before &amp;showing:</source>
        <translation>Verzögerung vor dem &amp;Einblenden:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1263"/>
        <source>&amp;Hide off screen</source>
        <translation>Ausblenden a&amp;ktivieren</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1294"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
</context>
<context>
    <name>Obconf::MainDialog</name>
    <message>
        <location filename="../theme.cpp" line="152"/>
        <source>Choose an Openbox theme</source>
        <translation>Auswahl des Openbox-Themas</translation>
    </message>
    <message>
        <location filename="../desktops.cpp" line="67"/>
        <location filename="../desktops.cpp" line="89"/>
        <location filename="../desktops.cpp" line="101"/>
        <source>(Unnamed desktop)</source>
        <translation>(Unbenannte Arbeitsfläche)</translation>
    </message>
    <message>
        <location filename="../mouse.cpp" line="56"/>
        <source>Custom actions</source>
        <translation>Benutzerdefinierte Aktionen</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="78"/>
        <source>About ObConf-Qt</source>
        <translation>Über ObConf-Qt</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="79"/>
        <source>A preferences manager for Openbox

Copyright (c) 2014-2015

Authors:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

The program is based on ObConf developed by the following developers.
* Dana Jansens &lt;danakj@orodu.net&gt;
* Tim Riley &lt;tr@slackzone.org&gt;
* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</source>
        <translation>Graphische Benutzeroberfläche zur Konfiguration von Openbox

Copyright (c) 2014-2015

Autor:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

Das Programm basiert auf ObConf, entwickelt von
* Dana Jansens &lt;danakj@orodu.net&gt;
* Tim Riley &lt;tr@slackzone.org&gt;
* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../archive.cpp" line="26"/>
        <source>&quot;%1&quot; was installed to %2</source>
        <translation>&quot;%1&quot; wurde nach %2 installiert</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="53"/>
        <source>&quot;%1&quot; was successfully created</source>
        <translation>&quot;%1&quot; wurde erfolgreich erstellt</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="89"/>
        <source>Unable to create the theme archive &quot;%1&quot;.
The following errors were reported:
%2</source>
        <translation>Erstellung des Themenarchivs &quot;%1&quot; ist fehlgeschlagen.
Die folgenden Fehlermeldungen wurden mitgeteilt:
 %2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="95"/>
        <location filename="../archive.cpp" line="180"/>
        <source>Unable to run the &quot;tar&quot; command: %1</source>
        <translation>&quot;tar&quot; Befehl %1 konnte nicht ausgeführt werden</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="115"/>
        <source>Unable to create directory &quot;%1&quot;: %2</source>
        <translation>Verzeichnis &quot;%1&quot; konnte nicht erstellt werden: %2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="138"/>
        <source>&quot;%1&quot; does not appear to be a valid Openbox theme directory</source>
        <translation>&quot;%1&quot; scheint kein korrektes Themenverzeichnis von Openbox zu sein</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="187"/>
        <source>Unable to extract the file &quot;%1&quot;.
Please ensure that &quot;%2&quot; is writable and that the file is a valid Openbox theme archive.
The following errors were reported:
%3</source>
        <translation>Datei &quot;%1&quot; kann nicht entpackt werden.
Bitte sicherstellen, dass &quot;%2&quot; beschrieben werden kann und die Datei ein korrektes Archiv mit einem Openbox Thema ist.
Folgende Fehlermeldungen wurden mitgeteilt:
%3</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="53"/>
        <source>ObConf Error</source>
        <translation>ObConf Fehler</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="58"/>
        <source>Copyright (c) 2003-2008   Dana Jansens
Copyright (c) 2003        Tim Riley
Copyright (c) 2007        Javeed Shaikh
Copyright (c) 2013        Hong Jen Yee (PCMan)

This program comes with ABSOLUTELY NO WARRANTY.
This is free software, and you are welcome to redistribute it
under certain conditions. See the file COPYING for details.

</source>
        <translation>Copyright (c) 2003-2008   Dana Jansens
Copyright (c) 2003        Tim Riley
Copyright (c) 2007        Javeed Shaikh
Copyright (c) 2013        Hong Jen Yee (PCMan)

Dieses Programm wird unter Ausschluss jeglicher Garantie zur Verfügung
gestellt.
Es handelt sich um freie Software,die unter Beachtung bestimmter
Voraussetzungen gerne weitergegeben werden darf, Näheres enthält die
Datei COPYING.

</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="73"/>
        <source>Syntax: obconf [options] [ARCHIVE.obt]

Options:
  --help                Display this help and exit
  --version             Display the version and exit
  --install ARCHIVE.obt Install the given theme archive and select it
  --archive THEME       Create a theme archive from the given theme directory
  --config-file FILE    Specify the path to the config file to use
</source>
        <translation>Übersicht: obconf [Optionen] [ARCHIVE.obt]

Optionen:
  --help                diesen Hilfetext ausgeben und Programm beenden
  --version             Version ausgeben und Programm beenden
  --install ARCHIVE.obt Thema aus angegebenem Archiv extrahieren und verwenden
  --archive THEMA       Archiv mit dem im genannten Verzeichnis befindlichen Thema erstellen
  --config-file DATEI   zu verwendende Konfigurationsdatei explizit angeben
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="97"/>
        <source>--install requires an argument
</source>
        <translation>--install benötigt ein Argument
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="103"/>
        <source>--archive requires an argument
</source>
        <translation>--archive benötigt ein Argument
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="109"/>
        <source>--config-file requires an argument
</source>
        <translation>--config-file benötigt ein Argument
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="206"/>
        <source>Platform Unsupported</source>
        <translation>Plattform nicht unterstützt</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="207"/>
        <source>ObConf-Qt is unsupported under Wayland.
</source>
        <translation>ObConf-Qt kann nicht benutzt werden in Wayland.
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="254"/>
        <source>Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.

Message: %1</source>
        <translation>Fehler bei der Auswertung der Konfigurationsdatei von Openbox. Die Konfigurationsdatei ist nicht in korrekter XML verfasst.

Nachricht: %1</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="241"/>
        <location filename="../obconf-qt.cpp" line="256"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="242"/>
        <source>Failed to load an rc.xml. You have probably failed to install Openbox properly.</source>
        <translation>Datei rc.xml konnte nicht geladen werden. Möglicher Weise wurde Openbox nicht korrekt installiert.</translation>
    </message>
</context>
</TS>
